import{s as H,e as _,f as g,c as d,h as I,j as v,d as f,i as h,k as b,b as p,g as C,a as V}from"./scheduler.CCSnUDNs.js";import{S as L,i as M,c as $,a as y,m as k,t as D,b as T,d as j}from"./index.BaOberT0.js";import{T as E}from"./0.C1v_il9P.js";import{R as W}from"./Ride.C-bF3bcc.js";function w(l){let e;function a(r,o){return r[0].dapp_wallet_cohesion.chain_id!=="yes"?F:B}let n=a(l),t=n(l);return{c(){e=_("div"),t.c(),this.h()},l(r){e=d(r,"DIV",{style:!0});var o=I(e);t.l(o),o.forEach(f),this.h()},h(){p(e,"display","flex"),p(e,"align-items","center"),p(e,"justify-content","center")},m(r,o){h(r,e,o),t.m(e,null)},p(r,o){n!==(n=a(r))&&(t.d(1),t=n(r),t&&(t.c(),t.m(e,null)))},d(r){r&&f(e),t.d()}}}function B(l){let e,a="<span>😁 The <b>Dapp</b> and <b>Wallet</b> report are on the same Chain ID.</span>";return{c(){e=_("div"),e.innerHTML=a,this.h()},l(n){e=d(n,"DIV",{class:!0,"data-svelte-h":!0}),C(e)!=="svelte-dwnkj"&&(e.innerHTML=a),this.h()},h(){V(e,"class","card p-4 variant-filled-primary")},m(n,t){h(n,e,t)},d(n){n&&f(e)}}}function F(l){let e,a='<div class="card p-2 variant-filled-error"><span>The <b>Dapp</b> and <b>Wallet</b> are not on the same Chain ID.</span></div>';return{c(){e=_("div"),e.innerHTML=a,this.h()},l(n){e=d(n,"DIV",{class:!0,"data-svelte-h":!0}),C(e)!=="svelte-o5nofp"&&(e.innerHTML=a),this.h()},h(){V(e,"class","card p-2 variant-filled-error")},m(n,t){h(n,e,t)},d(n){n&&f(e)}}}function R(l){let e,a,n,t,r,o;a=new E({props:{on_change:l[2]}}),t=new W({props:{on_change:l[3]}});let s=typeof l[0]=="object"&&typeof l[1]=="object"&&l[1].stage_name_connected.length>=1&&w(l);return{c(){e=_("div"),$(a.$$.fragment),n=g(),$(t.$$.fragment),r=g(),s&&s.c()},l(i){e=d(i,"DIV",{});var c=I(e);y(a.$$.fragment,c),n=v(c),y(t.$$.fragment,c),r=v(c),s&&s.l(c),c.forEach(f)},m(i,c){h(i,e,c),k(a,e,null),b(e,n),k(t,e,null),b(e,r),s&&s.m(e,null),o=!0},p(i,[c]){const m={};c&1&&(m.on_change=i[2]),a.$set(m);const u={};c&2&&(u.on_change=i[3]),t.$set(u),typeof i[0]=="object"&&typeof i[1]=="object"&&i[1].stage_name_connected.length>=1?s?s.p(i,c):(s=w(i),s.c(),s.m(e,null)):s&&(s.d(1),s=null)},i(i){o||(D(a.$$.fragment,i),D(t.$$.fragment,i),o=!0)},o(i){T(a.$$.fragment,i),T(t.$$.fragment,i),o=!1},d(i){i&&f(e),j(a),j(t),s&&s.d()}}}function S(l,e,a){let n=!1,t=!1;return[n,t,({freight:s})=>{a(0,n=s)},({pro_freight:s})=>{a(1,t=s)}]}class J extends L{constructor(e){super(),M(this,e,S,R,H,{})}}export{J as B};
//# sourceMappingURL=Bothy._PmHzXpO.js.map
